@@ -80,52 +80,6 @@ def test_geopandas(pyi_builder):
     )
 
 
-def tensorflow_onedir_only(test):
-    def wrapped(pyi_builder):
-        if pyi_builder._mode != 'onedir':
-            pytest.skip('Tensorflow tests support only onedir mode '
-                        'due to potential distribution size.')
-        test(pyi_builder)
-
-    return wrapped
-
-
-@importorskip('tensorflow')
-@tensorflow_onedir_only
-def test_tensorflow(pyi_builder):
-    pyi_builder.test_source(
-        """
-        from tensorflow import *
-        """
-    )
-
-
-# Test if tensorflow.keras imports properly result in tensorflow being collected.
-# See https://github.com/pyinstaller/pyinstaller/discussions/6890
-@importorskip('tensorflow')
-@tensorflow_onedir_only
-def test_tensorflow_keras_import(pyi_builder):
-    pyi_builder.test_source(
-        """
-        from tensorflow.keras.models import Sequential
-        from tensorflow.keras.layers import Dense, LSTM, Dropout
-        from tensorflow.keras.optimizers import Adam
-        """
-    )
-
-
-@importorskip('tensorflow')
-@tensorflow_onedir_only
-def test_tensorflow_layer(pyi_builder):
-    pyi_builder.test_script('pyi_lib_tensorflow_layer.py')
-
-
-@importorskip('tensorflow')
-@tensorflow_onedir_only
-def test_tensorflow_mnist(pyi_builder):
-    pyi_builder.test_script('pyi_lib_tensorflow_mnist.py')
-
-
 @importorskip('trimesh')
 def test_trimesh(pyi_builder):
     pyi_builder.test_source(
@@ -251,6 +205,15 @@ def test_markdown(pyi_builder):
         """)
 
 
+@importorskip('pylsl')
+def test_pylsl(pyi_builder):
+    pyi_builder.test_source(
+        """
+        import pylsl
+        print(pylsl.version.__version__)
+        """)
+
+
 @importorskip('lxml')
 def test_lxml_isoschematron(pyi_builder):
     pyi_builder.test_source(
@@ -480,43 +443,6 @@ def test_pydivert(pyi_builder):
         """)
 
 
-@pytest.mark.slow
-@importorskip('skimage')
-@pytest.mark.skipif(not is_module_satisfies('scikit_image >= 0.16'),
-                    reason='The test supports only scikit-image >= 0.16.')
-@pytest.mark.parametrize('submodule', [
-    'color', 'data', 'draw', 'exposure', 'feature', 'filters', 'future',
-    'graph', 'io', 'measure', 'metrics', 'morphology', 'registration',
-    'restoration', 'segmentation', 'transform', 'util', 'viewer'
-])
-def test_skimage(pyi_builder, submodule):
-    pyi_builder.test_source("""
-        import skimage.{0}
-        """.format(submodule))
-
-
-@pytest.mark.slow
-@importorskip('sklearn')
-@pytest.mark.skipif(not is_module_satisfies('scikit_learn >= 0.21'),
-                    reason='The test supports only scikit-learn >= 0.21.')
-@pytest.mark.parametrize('submodule', [
-    'calibration', 'cluster', 'covariance', 'cross_decomposition',
-    'datasets', 'decomposition', 'dummy', 'ensemble', 'exceptions',
-    'experimental', 'externals', 'feature_extraction',
-    'feature_selection', 'gaussian_process', 'inspection',
-    'isotonic', 'kernel_approximation', 'kernel_ridge',
-    'linear_model', 'manifold', 'metrics', 'mixture',
-    'model_selection', 'multiclass', 'multioutput',
-    'naive_bayes', 'neighbors', 'neural_network', 'pipeline',
-    'preprocessing', 'random_projection', 'semi_supervised',
-    'svm', 'tree', 'discriminant_analysis', 'impute', 'compose'
-])
-def test_sklearn(pyi_builder, submodule):
-    pyi_builder.test_source("""
-        import sklearn.{0}
-        """.format(submodule))
-
-
 @importorskip('statsmodels')
 @pytest.mark.skipif(not is_module_satisfies('statsmodels >= 0.12'),
                     reason='This has only been tested with statsmodels >= 0.12.')
@@ -558,49 +484,57 @@ def test_pyproj(pyi_builder):
 @importorskip('pydantic')
 def test_pydantic(pyi_builder):
     pyi_builder.test_source("""
+        import datetime
+        import pprint
+
         import pydantic
+
+
+        class User(pydantic.BaseModel):
+            id: int
+            name: str = 'John Doe'
+            signup_ts: datetime.datetime
+
+
+        external_data = {'id': 'not an int', }
+        try:
+            User(**external_data)
+        except pydantic.ValidationError as e:
+            pprint.pprint(e.errors())
         """)
 
 
-def torch_onedir_only(test):
-    def wrapped(pyi_builder):
-        if pyi_builder._mode != 'onedir':
-            pytest.skip('PyTorch tests support only onedir mode '
-                        'due to potential distribution size.')
-        test(pyi_builder)
-
-    return wrapped
-
-
-@importorskip('torchvision')
-@torch_onedir_only
-def test_torchvision_nms(pyi_builder):
+@requires('google-api-python-client >= 2.0.0')
+def test_googleapiclient(pyi_builder):
     pyi_builder.test_source("""
-        import torch
-        import torchvision
-        # boxes: Nx4 tensor (x1, y1, x2, y2)
-        boxes = torch.tensor([
-            [0.0, 0.0, 1.0, 1.0],
-            [0.45, 0.0, 1.0, 1.0],
-        ])
-        # scores: Nx1 tensor
-        scores = torch.tensor([
-            1.0,
-            1.1
-        ])
-        keep = torchvision.ops.nms(boxes, scores, 0.5)
-        # The boxes have IoU of 0.55, and the second one has a slightly
-        # higher score, so we expect it to be kept while the first one
-        # is discarded.
-        assert keep == 1
+        from googleapiclient import discovery, discovery_cache
+
+        API_NAME = "youtube"
+        API_VERSION = "v3"
+
+        for file in os.listdir(discovery_cache.DISCOVERY_DOC_DIR): # Always up to date
+            if file.startswith("youtube.v") and file.endswith(".json"):
+                API_NAME, API_VERSION = file.split(".")[:2]
+                break
+
+        # developerKey can be any non-empty string
+        yt = discovery.build(API_NAME, API_VERSION, developerKey=":)", static_discovery=True)
+        """)
+
+
+@importorskip('eth_typing')
+def test_eth_typing(pyi_builder):
+    pyi_builder.test_source("""
+        import eth_typing
     """)
 
 
-@importorskip('googleapiclient')
-def test_googleapiclient(pyi_builder):
+@importorskip("eth_utils")
+def test_eth_utils_network(pyi_builder):
     pyi_builder.test_source("""
-        from googleapiclient.discovery import build
-        """)
+        import eth_utils.network
+        eth_utils.network.name_from_chain_id(1)
+    """)
 
 
 @importorskip('plotly')
@@ -831,7 +765,7 @@ def test_pythonnet2(pyi_builder):
 
 @requires('pythonnet >= 3.dev')
 def test_pythonnet3(pyi_builder):
-    pyi_builder.test_source(f"""
+    pyi_builder.test_source("""
         from clr_loader import get_coreclr
         from pythonnet import set_runtime
         set_runtime(get_coreclr())  # Pick up and use any installed .NET runtime.
@@ -1206,6 +1140,16 @@ def test_gitlab(pyi_builder):
         """)
 
 
+@importorskip('graphql_query')
+def test_graphql_query(pyi_builder):
+    pyi_builder.test_source("""
+        from graphql_query import Operation, Query
+        hero = Query(name="hero", fields=["name"])
+        operation = Operation(type="query", queries=[hero])
+        print(operation.render())
+        """)
+
+
 @importorskip('shapely')
 def test_shapely(pyi_builder):
     pyi_builder.test_source("""
@@ -1302,19 +1246,19 @@ def test_pyshark(pyi_builder):
     )
 
 
-@importorskip('pyqtgraph')
 @importorskip('PyQt5')
+@importorskip('pyqtgraph')
 def test_pyqtgraph(pyi_builder):
     pyi_builder.test_source(
         """
         import pyqtgraph.graphicsItems.PlotItem
         import pyqtgraph.graphicsItems.ViewBox.ViewBoxMenu
         import pyqtgraph.imageview.ImageView
-        """,
-        pyi_args=['--exclude', 'PySide2', '--exclude', 'PySide6', '--exclude', 'PyQt6']
+        """
     )
 
 
+@importorskip('PyQt5')
 @importorskip('pyqtgraph')
 def test_pyqtgraph_colormap(pyi_builder):
     pyi_builder.test_source(
@@ -1325,8 +1269,8 @@ def test_pyqtgraph_colormap(pyi_builder):
     )
 
 
-@importorskip('pyqtgraph')
 @importorskip('PyQt5')
+@importorskip('pyqtgraph')
 def test_pyqtgraph_remote_graphics_view(pyi_builder):
     pyi_builder.test_source(
         """
@@ -1361,12 +1305,15 @@ def test_pyqtgraph_remote_graphics_view(pyi_builder):
         QtCore.QTimer.singleShot(1000, app.exit)
 
         sys.exit(app.exec_())
-        """,
-        pyi_args=['--exclude', 'PySide2', '--exclude', 'PySide6', '--exclude', 'PyQt6']
+        """
     )
 
 
+# Remove xfail once facebookresearch/hydra#2531 is merged.
 @importorskip('hydra')
+@xfail(
+    is_module_satisfies('PyInstaller >= 5.8'),
+    reason="uses deprecated PEP-302 functionality that was removed from PyInstaller's FrozenImporter.")
 def test_hydra(pyi_builder, tmpdir):
     config_file = str((Path(__file__) / '../data/test_hydra/config.yaml').resolve(strict=True).as_posix())
 
@@ -1473,7 +1420,7 @@ def test_compliance_checker(pyi_builder):
     # The test file - taken from the package's own test data/examples. Use an .nc file instead of .cdl one, because
     # loading the latter requires ncgen utility to be available on the system.
     pkg_path = get_module_attribute('compliance_checker', '__path__')[0]
-    input_file = Path(pkg_path) / 'tests/data/trajectory.nc'
+    input_file = Path(pkg_path) / 'tests/data/bad-trajectory.nc'
     assert input_file.is_file(), f"Selected test file, {input_file!s} does not exist! Fix the test!"
 
     pyi_builder.test_source("""
@@ -1519,3 +1466,457 @@ def test_minecraft_launcher_lib(pyi_builder):
         assert isinstance(minecraft_launcher_lib.utils.get_library_version(), str)
         '''
     )
+
+
+@importorskip('moviepy')
+def test_moviepy_editor(pyi_builder):
+    # `moviepy.editor` tries to access the `moviepy.video.fx` and `moviepy.audio.fx` plugins/modules via the
+    # `moviepy.video.fx.all` and `moviepy.video.fx.all` modules, which in turn programmatically import and
+    # forward all corresponding submodules.
+    pyi_builder.test_source("""
+        import moviepy.editor
+    """)
+
+
+@importorskip('customtkinter')
+def test_customtkinter(pyi_builder):
+    pyi_builder.test_source("""
+        import customtkinter
+    """)
+
+
+@importorskip('pylibmagic')
+def test_pylibmagic(pyi_builder):
+    pyi_builder.test_source("""
+        import pylibmagic
+        import os
+        import sys
+
+        bundle_dir = os.path.normpath(sys._MEIPASS)
+        pylibmagic_data_path = f"{bundle_dir}/pylibmagic"
+
+        files_to_assert = ["magic.mgc"]
+        if sys.platform == 'darwin':
+            files_to_assert.append("libmagic.1.dylib")
+        elif sys.platform.startswith('linux'):
+            files_to_assert.append("libmagic.so.1")
+
+        for file in files_to_assert:
+            assert os.path.isfile(f"{pylibmagic_data_path}/{file}"), \
+                f"The {file} was not collected to _MEIPASS!"
+    """)
+
+
+@importorskip('fastparquet')
+def test_fastparquet(pyi_builder):
+    pyi_builder.test_source("""
+        import fastparquet
+    """)
+
+
+@importorskip('librosa')
+def test_librosa(pyi_builder):
+    pyi_builder.test_source("""
+        import librosa
+
+        # Requires intervals.msgpack data file
+        import librosa.core.intervals
+
+        # Requires example files on import
+        import librosa.util.files
+    """)
+
+
+@importorskip('librosa')
+def test_librosa_util_function(pyi_builder):
+    # Test that functions from `librosa.util` that use `numba` vectorization can be run in frozen application.
+    pyi_builder.test_source("""
+        import librosa.util
+        import numpy as np
+
+        x = np.array([1, 0, 1, 2, -1, 0, -2, 1])
+        result = librosa.util.localmin(x)
+        expected = np.array([False,  True, False, False,  True, False,  True, False])
+        assert (result == expected).all()
+    """)
+
+
+@importorskip('sympy')
+def test_sympy(pyi_builder):
+    pyi_builder.test_source("""
+        import sympy
+    """)
+
+
+@importorskip('bokeh')
+def test_bokeh(pyi_builder):
+    pyi_builder.test_source("""
+        import bokeh
+    """)
+
+
+@importorskip('xyzservices')
+def test_xyzservices(pyi_builder):
+    pyi_builder.test_source("""
+        import xyzservices.providers
+        print(xyzservices.providers.CartoDB)
+    """)
+
+
+@importorskip('mistune')
+def test_mistune(pyi_builder):
+    pyi_builder.test_source("""
+        import mistune
+    """)
+
+
+@importorskip('jsonschema')
+def test_jsonschema(pyi_builder):
+    pyi_builder.test_source("""
+        import jsonschema
+
+        # Sample schema
+        schema = {
+            "type" : "object",
+            "properties" : {
+                "price" : {"type" : "number"},
+                "name" : {"type" : "string"},
+            },
+        }
+
+        jsonschema.validate(instance={"name" : "Eggs", "price" : 3.38}, schema=schema)
+
+        try:
+            jsonschema.validate(instance={"name" : "Eggs", "price" : "Invalid"}, schema=schema)
+        except jsonschema.ValidationError as e:
+            print(f"Validation error: {e}")
+    """)
+
+
+@importorskip('psutil')
+def test_psutil(pyi_builder):
+    pyi_builder.test_source("""
+        import psutil
+    """)
+
+
+@importorskip('litestar')
+def test_litestar(pyi_builder):
+    pyi_builder.test_source("""
+        from litestar import Litestar, get
+        from litestar.testing import TestClient
+        from typing import Dict, Any
+
+
+        @get("/sync", sync_to_thread=False)
+        def sync_hello_world() -> Dict[str, Any]:
+            return {"hello": "world"}
+
+
+        app = Litestar(route_handlers=[sync_hello_world])
+        client = TestClient(app)
+        response = client.get("/sync")
+        assert response.status_code == 200
+        assert response.json() == {"hello": "world"}
+    """)
+
+
+@importorskip('lingua')
+def test_lingua_language_detector(pyi_builder):
+    pyi_builder.test_source("""
+        from lingua import Language, LanguageDetectorBuilder
+
+        languages = [Language.ENGLISH, Language.FRENCH, Language.GERMAN, Language.SPANISH]
+        detector = LanguageDetectorBuilder.from_languages(*languages).build()
+
+        assert detector.detect_language_of("languages are awesome") == Language.ENGLISH
+    """)
+
+
+@importorskip('opencc')
+def test_opencc(pyi_builder):
+    pyi_builder.test_source("""
+        import opencc
+
+        cc = opencc.OpenCC('s2t')
+
+        assert cc.convert('开放中文转换') == '開放中文轉換'
+    """)
+
+
+@importorskip('jieba')
+def test_jieba(pyi_builder):
+    pyi_builder.test_source("""
+        import jieba
+
+        assert jieba.lcut('我来到北京清华大学') == ['我', '来到', '北京', '清华大学']
+    """)
+
+
+@importorskip('simplemma')
+def test_simplemma(pyi_builder):
+    pyi_builder.test_source("""
+        import simplemma
+
+        assert simplemma.lemmatize('tests', lang='en') == 'test'
+    """)
+
+
+@importorskip('wordcloud')
+def test_wordcloud(pyi_builder):
+    pyi_builder.test_source("""
+        import wordcloud
+
+        wordcloud.WordCloud().generate('test')
+    """)
+
+
+@importorskip('eng_to_ipa')
+def test_eng_to_ipa(pyi_builder):
+    pyi_builder.test_source("""
+        import eng_to_ipa
+    """)
+
+
+@importorskip('mecab')
+def test_mecab(pyi_builder):
+    pyi_builder.test_source("""
+        import mecab
+
+        mecab.MeCab()
+    """)
+
+
+@importorskip('khmernltk')
+def test_khmernltk(pyi_builder):
+    pyi_builder.test_source("""
+        import khmernltk
+    """)
+
+
+@importorskip('pycrfsuite')
+def test_pycrfsuite(pyi_builder):
+    pyi_builder.test_source("""
+        import pycrfsuite
+    """)
+
+
+@importorskip('pymorphy3')
+def test_pymorphy3(pyi_builder):
+    # Language availability depends on installed packages.
+    available_languages = []
+    if can_import_module('pymorphy3_dicts_ru'):
+        available_languages.append('ru')
+    if can_import_module('pymorphy3_dicts_uk'):
+        available_languages.append('uk')
+
+    pyi_builder.test_source("""
+        import sys
+        import pymorphy3
+
+        languages = sys.argv[1:]
+        print(f"Languages to test: {languages}")
+
+        for language in languages:
+            pymorphy3.MorphAnalyzer(lang=language)
+    """, app_args=available_languages)
+
+
+@importorskip('sudachipy')
+@importorskip('sudachidict_small')
+@importorskip('sudachidict_core')
+@importorskip('sudachidict_full')
+def test_sudachipy(pyi_builder):
+    pyi_builder.test_source("""
+        from sudachipy import Dictionary
+
+        Dictionary(dict='small').create()
+        Dictionary(dict='core').create()
+        Dictionary(dict='full').create()
+    """)
+
+
+@importorskip('laonlp')
+def test_laonlp(pyi_builder):
+    pyi_builder.test_source("""
+        import laonlp
+    """)
+
+
+@importorskip('pythainlp')
+def test_pythainlp(pyi_builder):
+    pyi_builder.test_source("""
+        import pythainlp
+    """)
+
+
+@importorskip('gmsh')
+def test_gmsh(pyi_builder):
+    pyi_builder.test_source("""
+        import gmsh
+    """)
+
+
+@importorskip('sspilib')
+def test_sspilib(pyi_builder):
+    pyi_builder.test_source("""
+        import sspilib
+
+        cred = sspilib.UserCredential(
+            "username@DOMAIN.COM",
+            "password",
+        )
+
+        ctx = sspilib.ClientSecurityContext(
+            "host/server.domain.com",
+            credential=cred,
+        )
+
+        print(ctx)
+    """)
+
+
+@importorskip('rlp')
+def test_rlp(pyi_builder):
+    pyi_builder.test_source("""
+        import rlp
+    """)
+
+
+@importorskip('eth_rlp')
+def test_eth_rlp(pyi_builder):
+    pyi_builder.test_source("""
+        import eth_rlp
+    """)
+
+
+@importorskip('z3c.rml')
+def test_z3c_rml_rml2pdf(pyi_builder):
+    pyi_builder.test_source("""
+        from z3c.rml import rml2pdf
+
+        rml = '''
+        <!DOCTYPE document SYSTEM "rml.dtd" >
+        <document filename="test.pdf">
+          <template showBoundary="1">
+            <!--Debugging is now turned on, frame outlines -->
+            <!--will appear on the page -->
+            <pageTemplate id="main">
+              <!-- two frames are defined here: -->
+              <frame id="first" x1="100" y1="400" width="150" height="200" />
+              <frame id="second" x1="300" y1="400" width="150" height="200" />
+            </pageTemplate>
+          </template>
+          <stylesheet><!-- still empty...--></stylesheet>
+          <story>
+            <para>Welcome to RML.</para>
+          </story>
+        </document>
+        '''
+
+        pdf_bytes = rml2pdf.parseString(rml)
+    """)
+
+
+@importorskip('freetype')
+def test_pyi_freetype(pyi_builder):
+    pyi_builder.test_source("""
+        import sys
+        import pathlib
+
+        import freetype
+
+        # Ensure that the freetype shared library is bundled with the frozen application; otherwise, freetype might be
+        # using system-wide library.
+
+        # First, check that freetype.FT_Library_filename is an absolute path; otherwise, it is likely using
+        # basename-only ctypes fallback.
+        ft_library_file = pathlib.Path(freetype.FT_Library_filename)
+        print(f"FT library file (original): {ft_library_file}", file=sys.stderr)
+        assert ft_library_file.is_absolute(), "FT library file is not an absolute path!"
+
+        # Check that fully-resolved freetype.FT_Library_filename is anchored in fully-resolved frozen application
+        # directory.
+        app_dir = pathlib.Path(__file__).resolve().parent
+        print(f"Application directory: {app_dir}", file=sys.stderr)
+        ft_library_path = pathlib.Path(ft_library_file).resolve()
+        print(f"FT library file (resolved): {ft_library_path}", file=sys.stderr)
+        assert app_dir in ft_library_path.parents, "FT library is not bundled with frozen application!"
+    """)
+
+
+@importorskip('vaderSentiment')
+def test_vadersentiment(pyi_builder):
+    pyi_builder.test_source("""
+        import vaderSentiment.vaderSentiment
+        vaderSentiment.vaderSentiment.SentimentIntensityAnalyzer()
+    """)
+
+
+@importorskip('langchain')
+def test_langchain_llm_summarization_checker(pyi_builder):
+    pyi_builder.test_source("""
+        import langchain.chains.llm_summarization_checker.base
+    """)
+
+
+@importorskip('seedir')
+def test_seedir(pyi_builder):
+    pyi_builder.test_source("""
+        import seedir
+    """)
+
+
+@importorskip('PyTaskbar')
+@pytest.mark.skipif(not is_win, reason='PyTaskbar is supported only on Windows')
+def test_PyTaskbar(pyi_builder):
+    pyi_builder.test_source("""
+            import PyTaskbar
+        """)
+
+
+@importorskip('celpy')
+def test_celpy(pyi_builder):
+    pyi_builder.test_source("""
+        import celpy
+    """)
+
+
+@importorskip('pygwalker')
+def test_pygwalker(pyi_builder):
+    pyi_builder.test_source("""
+        import pygwalker
+    """)
+
+
+@importorskip('pypylon')
+def test_pypylon(pyi_builder):
+    pyi_builder.test_source("""
+        from pypylon import pylon
+    """)
+
+
+@importorskip('osgeo')
+def test_osgeo(pyi_builder):
+    pyi_builder.test_source("""
+        from osgeo import osr
+        sr = osr.SpatialReference()
+        sr.ImportFromEPSG(4326)
+        assert(sr.EPSGTreatsAsLatLong())
+    """)
+
+
+@importorskip('falcon')
+def test_falcon(pyi_builder):
+    # https://github.com/falconry/falcon/blob/v3.1.3/examples/things.py
+    pyi_builder.test_source("""
+        import falcon
+    """)
+
+
+@importorskip('iso639')
+def test_iso639(pyi_builder):
+    pyi_builder.test_source("""
+        from iso639 import Lang
+        test = Lang("en")
+    """)
